Extract completed datasets from a gmm_imputation
Arguments
Value
When which selects one completion, a single completed dataset
(matrix, or data frame if the input was one); otherwise a list of them.
See also
Other imputation:
as_mids(),
gmm_imputation(),
gmm_impute(),
mechanism,
proxy_fmi(),
proxy_mnar_sensitivity(),
proxy_pool()