A gmm_fit is the result of fit_proxymix() (or one of the regime-specific
fitters). It inherits the mixture parameters of gmm and adds a record of
the target it was fitted to, the regime used, and the iteration
diagnostics.
Arguments
- weights, means, covariances, name, metadata
See gmm.
- target
The gmm_target the mixture was fitted to.
- regime
One of
"moment","sample","kld".- diagnostics
A list of regime-specific diagnostics (see
kld_trace(),ess_trace()).- converged
Logical scalar.
- iterations
Integer scalar.
- call
The matched call.
See also
Other classes:
autoplot.gmm_fit,
glance.gmm_fit,
gmm(),
gmm_counterfactual_law(),
gmm_dim(),
gmm_n_components(),
gmm_target(),
gmm_weights(),
is_proposal(),
tidy.gmm
Examples
samples <- matrix(stats::rnorm(200), ncol = 2)
tgt <- gmm_target_from_samples(samples)
fit <- fit_proxymix(tgt, N = 2L, regime = "sample", max_iter = 25L)
inherits(fit, "proxymix::gmm_fit")
#> [1] TRUE